#
# spec file for package rapid-photo-downloader
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
# Copyright (c) 2009-2011 Pascal Blesser pascal.bleser@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude ^typelib\\(Unity\\).*$
Name:           rapid-photo-downloader
Version:        0.9.36
Release:        1.4
Summary:        Parallel downloader for camera and smartphone photos
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://damonlynch.net/rapid/
Source:         https://launchpad.net/rapid/pyqt/%{version}/+download/%{name}-%{version}.tar.gz
Source1:        https://launchpad.net/rapid/pyqt/%{version}/+download/%{name}-%{version}.tar.gz.asc
Source2:        series
# PATCH-FEATURE-OPENSUSE disable-version-check.patch
Patch0:         disable-version-check.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3-devel >= 3.10
Requires:       python3 >= 3.10
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       exiftool
BuildRequires:  python3-PyPrind >= 2.9.4
Requires:       python3-PyPrind >= 2.9.4
BuildRequires:  python3-arrow >= 0.9.0
Requires:       python3-arrow >= 0.9.0
BuildRequires:  python3-base >= 3.6
BuildRequires:  python3-Babel
Requires:       python3-Babel
BuildRequires:  python3-colorlog >= 2.6
Requires:       python3-colorlog >= 2.6
BuildRequires:  python3-colour
Requires:       python3-colour
BuildRequires:  python3-easygui >= 0.98.1
Requires:       python3-easygui >= 0.98.1
BuildRequires:  python3-gobject
Requires:       python3-gobject
BuildRequires:  python3-gobject-Gdk
Requires:       python3-gobject-Gdk
BuildRequires:  python3-gphoto2 >= 1.8.0
Requires:       python3-gphoto2 >= 1.8.0
BuildRequires:  python3-packaging
Requires:       python3-packaging
BuildRequires:  python3-psutil >= 3.4.2
Requires:       python3-psutil >= 3.4.2
BuildRequires:  python3-pymediainfo >= 2.2.0
Requires:       python3-pymediainfo >= 2.2.0
BuildRequires:  python3-python-dateutil >= 2.7
Requires:       python3-python-dateutil >= 2.7
BuildRequires:  python3-PyPrind >= 2.9.4
Requires:       python3-PyPrind >= 2.9.4
BuildRequires:  python3-pyxdg >= 0.25
Requires:       python3-pyxdg >= 0.25
BuildRequires:  python3-pyzmq >=  16.0.2
Requires:       python3-pyzmq >=  16.0.2
BuildRequires:  python3-requests
Requires:       python3-requests
BuildRequires:  python3-show-in-file-manager >= 1.1.2
Requires:       python3-show-in-file-manager >= 1.1.2
BuildRequires:  python3-sortedcontainers
Requires:       python3-sortedcontainers
BuildRequires:  python3-tornado
Requires:       python3-tornado
BuildRequires:  python3-tenacity
Requires:       python3-tenacity
# needed since 0.9.20 for SVG assets
BuildRequires:  libQt5Svg5
Requires:       libQt5Svg5
BuildRequires:  python3-qt5 >= 5.15.6
Requires:       python3-qt5 >= 5.15.6

BuildArch:      noarch

# For heif support. we can not package the libraries in the distro but if e.g. packman provides the package we should pull it.
Recommends:     python3-pyheif
Recommends:     python3-Pillow >= 5.1.0
# iphone support. new in 0.9.27a1
Requires:       ifuse
Requires:       imobiledevice-tools

%description
Rapid Photo Downloader downloads images in parallel from multiple devices,
from every camera supported by gphoto2, including smartphones.

RPD has a timeline, which groups photos and videos based on how much
time elapsed between consecutive shots. It can be used to identify
photos and videos taken at different periods in a single day or over
consecutive days.

%lang_package

%prep
%autosetup -p1
find raphodo -type f -name '*.py' -exec sed -i -e '/^#!\//, 1d' {} \;

%build
python3 setup.py build

%install
python3 setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot}

%find_lang %{name}
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{python3_sitelib}

%files
%doc README.md CHANGES.md RELEASE_NOTES.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/metainfo/net.damonlynch.rapid_photo_downloader.metainfo.xml
%{_datadir}/applications/net.damonlynch.rapid_photo_downloader.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%{_datadir}/solid/actions/net.damonlynch.rapid_photo_downloader.desktop
%{_mandir}/man1/%{name}.1%{ext_man}
%{python3_sitelib}/raphodo
%{python3_sitelib}/rapid_photo_downloader-%{version}*-info

%files lang -f %{name}.lang

%changelog
* Sun Mar  3 2024 Marcus Rueckert <mrueckert@suse.de>
- Cleanup Requires/BuildRequires
  - drop unused python3-cairo
  - drop < 3.8 requirement python3-importlib-metadata
  - add python3-packaging
* Sun Mar  3 2024 Marcus Rueckert <mrueckert@suse.de>
- refresh disable-version-check.patch to apply without fuzz again
- remove fix-build-with-setuptools67.patch: no longer needed
- track series file as source for easier quilt usage
* Sun Mar  3 2024 Marcus Rueckert <mrueckert@suse.de>
- bump minimum python to 3.10
- sync with requirements.txt
* Sun Mar  3 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.9.36
  - Rapid Photo Downloader 0.9.35 requires Python 3.10 or newer.
  - Rapid Photo Downloader 0.9.19 introduced support for HEIF /
    HEIC files. The
    [documentation](https://damonlynch.net/rapid/documentation/#heifheic)
    goes into details.
  - Version 0.9.19 also introduced much improved support for
    high-resolution displays. Consult the
    [documentation](https://damonlynch.net/rapid/documentation/#highdpi)
    to learn more.
  - If thumbnailing fails to finish but no error is reported, that
    could indicate Exiv2 has crashed. See the [documentation](
    https://damonlynch.net/rapid/documentation/#miscellaneousnpreferences)
    for how to resolve the problem:
  - On some systems, Rapid Photo Downloader cannot use gstreamer to
    generate video thumbnails for all common video files. Install
    the good and libav plugins for gstreamer to solve this problem.
    In Debian and Ubuntu-like systems, the packages are
    gstreamer1.0-libav gstreamer1.0-plugins-good On Fedora, the
    packages are gstreamer1-plugins-good and gstreamer1-libav.
    Fedora users can enable the rpmfusion.org free repository to be
    able to install gstreamer1-libav.
  - Display a warning message window when the user selects an
    invalid download destination.
  - Highlight Timeline cell when the mouse is hovering over it.
  - Fix bug
    [#121](https://github.com/damonlynch/rapid-photo-downloader/issues/121):
    No feedback provided when invalid destination chosen in
    download panel.
  - Fix bug
    [#122](https://github.com/damonlynch/rapid-photo-downloader/issues/122):
    Application crashes on start on openSUSE Tumbleweed. Thanks to
    Bozhin Karaivanov for the fix.
  - Catch GLib errors like g-io-error-quark when checking the
    results of mount operations.
  - Update Albanian, Dutch, Hungarian, Norwegian BokmÃ¥l, Russian
    and Spanish translations.
- Changes from 0.9.35
  - Remove `install.py` script, built-in updater and new version
    check.
  - Python 3.10 or newer is now required.
  - New Python packet requirement: packaging.
  - Fix bug
    [#85](https://github.com/damonlynch/rapid-photo-downloader/issues/85):
    Exception while selecting generation scheme from download
    subfolder menu with more than five custom presets.
  - Fix bug
    [#50](https://github.com/damonlynch/rapid-photo-downloader/issues/50):
    Confirm before removing all presets for custom renaming or
    subfolder generation.
  - Fix bug
    [#49](https://github.com/damonlynch/rapid-photo-downloader/issues/49):
    Enable deletion of individual custom renaming and subfolder
    generation preset.
  - Re-enabled Ctrl-Q shortcut key for quiting when running under
    WSL.
  - Limit the default number cores used to generate thumbnails to
    8 (or the number of physical CPU cores if lower). Previously
    the limit was the number of physical CPU cores, which is
    nonsensical on high core count systems.
  - Fix bug
    [#110](https://github.com/damonlynch/rapid-photo-downloader/issues/110):
    ExifTool not called during rename process.
  - Fix bug
    [#112](https://github.com/damonlynch/rapid-photo-downloader/issues/112):
    QWIDGETSIZE_MAX import error.
  - Conform version indentifier in `setup.py` to PEP 440 which is
    enforced with setuptools >= 66.0.0. Thanks to stratakis for
    the fix.
  - Eliminate use of depreciated pkg_resources.
  - Conform to changes in package python-gphoto2 2.5.0.
  - Update Albanian, Brazilian Portuguese, Danish, Dutch,
    Hungarian, Japanese, Polish, Russian, and Spanish
    translations.
* Tue Apr 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add fix-build-with-setuptools67.patch: Fix build with
  pyton-setuptools 67.x.
* Wed Nov  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.9.34:
  * avoid infinite loop when detecting setuptools install status in
    install.py script.
* Sun May  8 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.9.33
  * Enhance `install.py` script to not install unnecessary H.265
    dependencies now that pyheif includes them itself.
  * Fix implementation of bug fix #59: Handle cameras that nest
    dual card slots in subfolders like the Fujifilm X-T3.
- Release 0.9.32
  * Fix visual bug where right side user interface panels were not
    properly framed when first shown.
  * Fix bug #54: Use `exiv2` to read CR3 metadata when available.
    Please note: `exiv2` must be built with CR3 support, which is
    currently not the  default. To determine if your Linux
    distribution has enabled CR3 support, with Rapid Photo
    Downloader 0.9.32 or newer, run from the command line:
    `rapid-photo-downloader --detailed-version`
- Release 0.9.31
  * Update Hungarian, Japanese and Russian translations.
- Release 0.9.30
  * Fix bug #69: Exception when prompting for survey when locale is
    not English.
  * Fix bug #68: Devices part of user interface does not resize
  when a device is removed.
  * Fix bug when rendering device download progress bar when
    multiple devices are used under Python 3.10.
  * Update Dutch and Spanish translations.
- Release 0.9.30b1
  * Fix bug #59: Handle cameras that nest dual card slots in
  subfolders like the Fujifilm X-T3.
  * Fix bug #67: Crash when determining user interface size.
  * Update Albanian and Hungarian translations.
- Release 0.9.29
  * Fix bug #53: Adapt to small screens. Rapid Photo Downloader can
    now be resized to fit to tiny screens. Part of the fix involves
    changes in the ways the download sources (Devices and This
    Computer) and the Timeline are placed in the left-side of the
    user interface. When a scroll bar is necessary to fit in these
    interface elements, a single scroll bar will now extend from
    the Devices to the Timeline. When you scroll down to view the
    entirety of the Timeline, if the Timeline is big enough the
    download sources will scroll up out of sight.
  * Change the button to synchronize scrolling between the Timeline
    and thumbnails to a double arrow. It now changes color to
    reflect its state. The button's behavior is described in the
    documentation.
  * Make the Timeline remember its position when the time elapsed
    between consecutive shots is changed using the slider.
  * Make the user interface look cleaner and more consistent,
    especially regarding scrollbars and frames.
  * Enforce the use of the Qt 5 Fusion theme. Some Linux
    distribution Qt 5 themes can make the program's user interface
    look bad because of differing assumptions about design elements
    like scroll bars and frames. If you want to use your system's
    theme, use the command line option `--force-system-theme`.
  * Fix bug where various user interface elements would effectively
    be invisible when the system theme is dark, also known as
    "dark mode". Please note dark mode will likely work in the
    program only if the PyQt5 package provided by your Linux
    distribution is being used.
  * Fix bugs #61, #58, and #1958892: setuptools >= 60.0 failing.
    Some versions of setuptools >= 60.0 can fail on many if not all
    Linux distributions. The install.py script now uninstalls
    versions of pip, setuptools and wheel that were installed with
    pip if the versions provided by the Linux distribution are new
    enough. If the versions provided are too old to be fully
    functional, pip and wheel are updated, and setuptools is
    upgraded to a version < 60.0.
  * Fix bug #64: Warning dialog fails to appear when iOS device
    utility applications are missing, causing a crash when an iOS
    device is inserted.
  * Fix bug #56: Compress bug report tars using gzip, facilitating
    upload to GitHub issues. GitHub does not accept .tar files. It
    does accept .tar.gz files.
  * Fix bug #43: Add preference to handle time zone and daylight
    savings changes. See the program documentation for details
    about what this change is and why it is needed.
  * Fix bug #47: Thumbnail generation overwrites Job Code applied
    to files before thumbnails are generated.
  * Fix bug #55: Updated sequence numbers not used when changed in
    user interface between file downloads.
  * Add preference option to automatically mount devices not
    already automatically mounted. This new option is on by
    default. The program already did this on KDE, but it could not
    be turned off. It can now be turned off. Regardless of the
    Linux desktop used, leaving it on is helpful for when the
    operating system does not automatically mount devices like
    memory cards itself. A desktop like KDE can choose to not
    automatically mount devices, for instance. Meanwhile, sometimes
    Linux desktop code contains bugs that results in devices
    failing to mount even when they were supposed to.
  * Fix bug to properly size thumbnails and hamburger menu on high
    DPI screens with recent releases of Gnome and other desktops
    that use xsettings.
  * Correctly check latest available PyQt5 package version on
    Fedora and CentOS.
  * Drop support for CentOS 7.5.
  * Remove dependency on fuse in install.py script due to emerging
    introduction of the fuse3 package. In almost all circumstances,
    the ifuse package should correctly specify the correct version
    of fuse to depend on, making the explicit declaration of fuse
    as a dependency in the install.py script wrong.
  * Fix bug to correctly display the number of files available for
    download after some files have been manually marked as already
    downloaded.
  * Update Albanian, Catalan, Dutch, Hungarian, Italian, Japanese,
    Russian, Spanish, Swedish and Turkish translations.
- Release 0.9.28
  * Fix bug #44: Exception at startup when XDG_CURRENT_DESKTOP is
    not set or set to unexpected value.
  * Fix bug #45: Make toggle switch behave consistently with other
    UI toolkits.
  * Fix bug #1955755: Exception occurred when probing device with
    malformed device path.
  * Update Turkish translation.
- Release 0.9.27
  * Purge calls to unmaintained Python package rawkit, which was an
    optional dependency.
  * Fix bug to always display the correct value for showing system
    directories when right-clicking on Photo and Video
    destinations, as well as This Computer.
  * When running under WSL 2, account for default value
    %%USERPROFILE%% when probing registry to determine Pictures and
    Videos user folder locations.
  * Add support for CentOS Stream 8 and CentOS 8 to install.py
    script. Thanks to Neal Gompa for identifying the cause of a
    problem when querying dnf under CentOS Stream 8 and providing
    the fix for it.
  * Update Czech, Dutch, French, Hungarian, Polish, Russian and
    Spanish translations.
  * Correct Albanian language attribution in About dialog box.
  * Read in much larger chunk of RAF files on cameras to read
    metadata. This slows performance, but is necessary on newer RAF
    files, which have larger embedded JPEGs that are placed before
    the metadata in the file.
- Release 0.9.27b2
  * Enable running under WSLg and WSL2 on Windows 11. Not all
    features are supported. See the program documentation
  * By default only non-system directories are now shown in the
    directory listings for Photo and Video destinations, as well as
    This Computer. Right- click in the directory listings to enable
    showing all system directories.
  * The install.py script now updates the mime info cache, meaning
    the program should now appear as an option to handle
    photographic media in file managers when installed using this
    script.
  * Fix bug #1946407: another compatibility fix for Python 3.10
    that 0.9.27b1 and 0.9.27a3 did not fully resolve.
  * Don't crash when showing photo or video in file manager after
    right-clicking on thumbnail and no file is selected.
  * Update Albanian, Dutch and Swedish translations.
- Release 0.9.27b1
  * Use Python module Show-in-File-Manager to display files in the
    operating system's file manager. Linux distribution packagers:
    this is a required module.
  * New Python module requirement for Python versions earlier than
    3.8: importlib_metadata.
  * All selected files will now be opened in the file manager when
    right- clicking on a photo or video in the main window and
    "Open in File Browser" is activated. Previously only the file
    being right-clicked on would be opened.
  * Fix bug #1946407: another compatibility fix for Python 3.10
    that 0.9.27a3 did not fully resolve.
  * Fix bug #33 SystemError: PY_SSIZE_T_CLEAN macro must be defined
    for '#' formats on Python 3.10. The solution is to install PyQt
    5.15.6 or newer when using Python 3.10, which the install.py
    script now does.
  * Fix bug where downloading from a camera that was already in use
    would fail because generating an error message would cause an
    exception.
  * Disable viewing files still on a camera in the operating
    system's file manager when on KDE.
- Drop oldsetuptools.patch: Old distribution does not support
  minimum Python version
- Replace obsolete pygobject2 requirement with the real one
* Tue Oct 26 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.27a3
  - Fixed bug #1946407: Work around apparent float to int
    conversion when calling Qt from Python 3.10 on Fedora 35 beta.
  - Fixed bug #33: Files with unique identifier added via error
    handling are not marked as downloaded.
  - Added folder 'Screenshots' to list of ignored paths. Remove
    this folder from the list of ignored paths in the program
    Preferences dialog if you do wish to download from a path that
    contains this folder.
  - Fix bug #1924933: Exception when scanning device with
    problematic connection.
  - Fix bug #1909904: python3-libunity package dumps core on
    Fedora. The install.py script will now uninstall
    python3-libunity if it is found on the system, as using it
    causes a calling program like Rapid Photo Downloader to crash.
  - Include Python package setuptools in README.md listing of
    required of runtime packages. It has been required for some
    time, but the README did not specify it.
  - The install.py script will no longer install pyheif on
    Raspberry Pi OS because user feedback indicates pyheif fails to
    build on that OS. If pyheif does in fact build on your install
    of Raspberry Pi OS, you can install it using Python's pip.
* Sat Jul 31 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.27a2
  - Fix bug #30: iPhone7 serial number format not recognized.
  - Fix bug #1938341: Albanian translations not compiled.
* Wed Jul 28 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.27a1
  - iOS devices are now accessed using a software library written
    specifically to communicate with iOS devices, libimobiledevice.
    Previously, gPhoto2 was used, but gPhoto2 is unreliable with
    iOS because it appears Apple does not follow the PTP standard.
    Please note that on some systems, it can take some minutes for
    the iOS device to appear after it has been plugged in.
  - Python 3.6 is now the minimum Python version.
  - Update install.py script to correctly enable Power Tools
    repository on CentOS 8, and the Qt5 wayland package on Fedora
    and CentOS 8.
  - Update Albanian and Polish translations.
- new Requires imobiledevice-tools ifuse fuse
* Mon Jan 25 2021 aloisio@gmx.com
- Apply typelib(Unity) unconditionally
* Fri Dec 25 2020 Marcus Rueckert <mrueckert@suse.de>
- according to upstream pillow is only required for thumbnails for
  heif files. downgrade the requires to recommends.
* Fri Dec 25 2020 Marcus Rueckert <mrueckert@suse.de>
- add back requires filter for the unity typelib on TW. The library
  got dropped.
* Fri Dec 25 2020 Marcus Rueckert <mrueckert@suse.de>
- sync package BuildRequires/Requires with requirements.txt
* Fri Dec 25 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.26
  - Fix bug #1909252: crash against undefined unity launcher entry. Thanks to
    Guy Delamarter for the patch.
  - Ensure in-program upgrade feature continues to function on systems with
    Python 3.5.
  - Move translators credits into separate button in the About dialog window, and
    associate recent translators with their language.
  - Update Brazilian Portuguese, Danish, Dutch, French, Japanese, Norwegian
    Bokmal, Russian, Serbian, Spanish and Turkish translations. Thank you to new
    translator Rubens Stuginski Jr for the work done on the Brazilian Portuguese
    translation.
- changes from 0.9.25
  - When a new Job Code is entered before a download and no files are selected,
    the Job Code is automatically saved. When entering a Job Code, "Remember this
    Choice" is now labelled as "Remember this Job Code".
  - Fix bug #1889770: Fails to run - Could not load the Qt platform plugin
    "xcb".
  - Fix bug #1906272: Exception while displaying tooltip for thumbnail of file
    downloaded from a removed device.
  - Fix bug #1891659: Exception when encountering invalid block device.
  - Fix bug #1881255: Unhandled exception when system file manager entry is
    malformed. The AppImages for RawTherapee and ART can have an unfortunate bug
    in which they wrongly sets themselves to be the path to the desktop's
    default file manger. Rapid Photo Downloader no longer crashes when trying to
    work with that incorrect setting.
  - Bump up minimum Python version supported to Python 3.5.
  - Don't install support library libunity on Fedora. Libunity has a serious
    bug on Fedora 33. Libunity provides emblems and progress bars on launchers on
    desktops like KDE and Ubuntu's flavor of Gnome.
  - Fedora 32 is now the minimum supported version of Fedora. Please note Fedora
    33 is not recommended for now, because of an issue with Python 3.9 and
    Python threads seen when running Rapid Photo Downloader in Fedora 33. In
    contrast to Fedora 33, Ubuntu 21.04 with Python 3.9 works as expected.
  - When installing on Debian using the install.py script, ignore any version
    number information (or lack thereof) in /etc/os-release.
  - When using the install.py script, don't install PyQt5 and python3-gphoto2
    from PyPi when the Linux distribution's package is relatively recent. Also:
    don't default to installing the PyPi Python tools pip, setuptools, and wheel
    using pip when the system packages are relatively recent, and don't install
    unsupported versions these same packages on Python 3.5.
  - Bump up minimum version of python package easygui to 0.98.1.
  - Bump up minimum version of python-dateutil to allow recent versions of
    arrow to function. When using the install.py script, don't install
    unsupported versions of arrow or pymediainfo on Python 3.5.
  - When using the install.py script, don't install the unmaintained python
    package rawkit on systems that do not contain libraw 0.16 or 0.17.
  - Update Danish, Dutch, French, German, Hungarian, Russian, Serbian, and
    Spanish translations. Add partially translated Albanian translation.
* Mon May 11 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.24
  - Added support for Ubuntu Kylin and Pop!_OS 20.04.
  - Provide the option of automatically creating a tar file of
    program configuration file and log files when submitting a bug
    report.
  - Fixed bug #1875268: Overly long download source name
    limitlessly expands window width.
  - Fixed bug #1876344: Unable to generate thumbnails or download
    from Fujifilm X-H1.
  - All message box buttons should now be able to be translated (or
    able to be translated).
  - Updated Chinese (Simplified), Czech, Dutch, French, German,
    Hungarian, Serbian, Spanish and Turkish translations.
- Changes from 0.9.23
  - Fixed bug #1872188: sqlite3.OperationalError when generating
    thumbnails.
  - Fixed bug #1873057: Add ORI to list of supported image formats.
  - Fixed bug #1873233: RAW and JPG don't synchronize when using
    stored number.
  - Fixed bug where HEIF/HEIC thumbnails on a camera were not being
    generated until they were downloaded.
  - When generating video thumbnails for phones and tablets, the
    entire video will now be downloaded and cached. Previously only
    a portion of the video was downloaded, in the hope that this
    portion could generate the thumbnail, but unfortunately it did
    not always render. This new behavior will slow down thumbnail
    generation, but does ensure the thumbnail will be rendered. If
    you object to this new behavior or know of a better approach,
    please share your thoughts in the discussion forum:
    https://discuss.pixls.us/c/software/rapid-photo-downloader
* Sat Apr 11 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.22
  - Fixed bugs where camera insertion and removal was not being
    detected in some circumstances. In KDE, it was camera removal.
    In Gnome-like systems where auto mounting of cameras is
    disabled or not functional, it was insertion.
  - More robustly handle a camera being unexpectedly removed during
    scanning, thumbnailing, and copying files.
  - Fixed bug #1871649: Window corruption when application scaling
    enabled on certain desktop environments. The application now
    uses Qt and Gdk to query whether any monitor has scaling
    enabled. If no scaling is enabled on any monitor, then Rapid
    Photo Downloader will not enable automatic scaling.
  - New package dependency:
    Python 3 gobject introspection for Gdk 3.0
* Mon Mar 23 2020 Marcus Rueckert <mrueckert@suse.de>
- removed all manual typelib requires again as we fixed the
  underlying problem in libdbusmenu
* Sun Mar 22 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.20
  - Added support for program icon progress bars and badge counts
    on any desktop that supports the Unity LauncherEntry API, not
    just Ubuntu Unity or Gnome running under Ubuntu. (The Unity
    LauncherEntry API is used by desktops other than Unity and
    Ubuntu Gnome, e.g. KDE, Dash to Panel.)
  - Added missing property StartupWMClass to the program's desktop
    file. It's now possible to add the Rapid Photo Downloader
    launcher as a Favorite to the Gnome Shell dock and not have it
    appear as a duplicate entry when the program runs. This fix
    also enables program icon progress bars and badge counts under
    Gnome Shell extensions that support them.
  - Implemented feature request in bug #1810102: cannot change
    language in program preferences. You can now specify the
    language you want the user interface to display in regardless
    of the system locale setting.
  - Fixed problems in setup.py. Made requirements.txt more
    conformant.
  - Better handle missing ExifTool on startup.
- refreshed disable-version-check.patch
- remove the typelib requires exclude as rpd now shows the progress
  with libunity
- add requires for new dependencies:
  - python3-Babel
  - libQt5Svg5
  - typelib(Unity) = 7.0
  - typelib(UnityExtras) = 7.0
- add temporary requires that should be pulled by typelib(Unity)
  - typelib(Dbusmenu) = 0.4
  - typelib(Dee) = 1.0
* Tue Mar 17 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.19
  - Fixed errors in appstream metainfo file.
  - To better conform to appstream metadata requirements, renamed
    destktop and metadata files to
    net.damonlynch.rapid_photo_downloader.desktop and
    net.damonlynch.rapid_photo_downloader.metainfo.xml. The
    metainfo file is now installed in share/metainfo/, not
    share/appdata/.
  - Added Zorin OS to install.py script.
  - Only install symlinks to the program in a bin directory the
    users's home directory (i.e. ~/bin) if necessary. On recent
    installations of Debian / Ubuntu / LinuxMint etc. with a
    default profile setup, this is no longer necessary.
  - When uninstalling the program that was previously installed
    with install.py script, remove any symlinks to it created in
    ~/bin.
  - Removed setup.cfg configuration file.
  - Removed notification informing the Timeline or provisional
    download folders was rebuilt.
  - Updated Dutch, Hungarian, Russian, Spanish, Russian, and
    Turkish translations.
  - Improved fix for a bug where thumbnails would not be able to
    have their checkmark set on or off with the mouse on recent
    versions of Qt. The fix in 0.9.19b2 did not always work. The
    environment variable RPD_THUMBNAIL_MARK_FIX introduced in
    0.9.19b2 is no longer needed, and will be ignored.
  - Fixed bug #1842060: Wrong value saved for stored number.
  - Updated Czech, Dutch, French, and Spanish translations.
  - Fixed a bug where thumbnails would not be able to have their
    checkmark set on or off with the mouse on recent versions of
    Qt. See the release notes for details.
  - Improved visual appearance on high DPI screens.
  - Added HEIF / HEIC support. See the Release Notes for details.
  - Added support for CentOS 8 to installer script. Dropped support
    for Fedora 29 and older. Installer script no longer installs
    PyQt5 from PyPI on KDE Neon, because KDE Neon PyQt5 package is
    always up-to-date.
  - Added '__MACOSX' and to list of paths to ignore while scanning
    a device for photos and videos, and if the list of ignored
    paths is customized, add it and 'THMBNL' to the existing list
    of ignored paths.
  - No longer look for photos or videos in any directory on a
    camera or phone that contains a '.nomedia' file.
  - Made Timeline and thumbnails render more quickly and accurately
    on displays with fractional scaling.
  - Fixed bug #1861591: install.py should handle cases with no LANG
    variable set.
  - Fixed bug #1833525: when using the filename and subfolder name
    preference editor, under some desktop styles the example file
    and subfolder names would shrink to the extent they would be
    truncated.
  - Fixed bug where Rapid Photo Downloader would crash when the
    Preferences dialog window was closed with the escape key.
  - Fixed bug where under some desktop styles the right side panel
    would always be open even if it had been closed when Rapid
    Photo Downloader last exited.
  - Improved support for high DPI screens. Requires Qt5.6 or newer.
    Please report any remaining problems when running on high DPI
    screens. For now, if you change the desktop's screen scaling
    while Rapid Photo Downloader is running, please restart it.
- add recommends for python3-pyheif
* Mon Mar 16 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.18
  Fixed several important bugs that could cause installation to
  fail. and a bug that could cause Rapid Photo Downloader when
  displaying some date/times in locales not fully translated in the
  Python module Arrow.
  Changelog:
  - Fixed bug in install.py script which meant the most recent
    version of PyQt5 failed to install because pip failed to build
    it. The solution is to update the user's copy of pip to the
    latest version (not the system-wide version).  If this is not
    what you want, you can downgrade pip for your user after
    program installation. See the release notes for more details.
  - Fixed bug #1857144: with newer versions of the Python date time
    module Arrow, if Arrow had not been translated to use the
    user's locale, Arrow will generate an exception when displaying
    the humanized form of some dates, causing Rapid Photo
    Downloader to crash. Now Rapid Photo Downloader reverts to
    English for any humanized string that Arrow fails to handle in
    the user's locale.
  - Fixed bug #1853775: install.py script did not properly handle
    upgrading pip version < 9.0 when installing into a virtual
    environment, looping forever.
  - Added Turkish translation. Thank you to Ilker Alp for the
    translation.  Updated Brazilian Portuguese, Finnish, German,
    Indonesian, Italian, Polish, and Spanish translations.
* Sat Oct  5 2019 Marcus Rueckert <mrueckert@suse.de>
- add BuildRequires for all our dependencies to make sure we have
  the right versions still in the distro
* Sat Oct  5 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 0.9.17
  - Fixed bug #1840499: Crash when python library arrow is older
    than version 0.9.0
  - Suppress parsing warnings issued by python library arrow
    version >= 0.14.3 and < 0.15.0.
  - Allow the use of the Python instance that the install.py script
    is invoked with on Gentoo systems.
  - Updated Polish translation.
- changes from 0.9.16
  - Fixed bug #1839699 where program would fail to start when the
    python library arrow 0.4.15 or newer is installed.
  - Added the directory THMBNL to the standard list of ignored
    directories. This directory is used on some Sony cameras.
  - Added %%f argument to Exec component of desktop file,
    potentially fixing problem with the program not appearing in
    Gnome's list of applications to deal with memory cards or
    cameras.
  - Updated Polish translation.
- changes from 0.9.15
  - Updated Brazilian Portuguese, Czech, Dutch, French, Hungarian,
    Japanese, Kabyle, Norwegian Nynorsk, Russian and Spanish
    translations.
* Sun Apr  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.14
  * Fix bug #1821917: Error generating Timeline with Arrow
    0.13.1.
  * Fix bug #1817481: Error deleting sample file at program exit.
  * Fix bug #1810572: Error getting camera configuration on
    certain cameras.
  * Again fix bug #1801504: PyQt5_sip not installed or upgraded
    for local user when system copy already installed (bug seen
    on Fedora 29). The fix in 0.9.13 did not always work.
  * When installing using the install.py script, upgrade pip if
    its version is less than 9.0.
  * Disable the program's built-in upgrade procedure when
    running from within a python virtual environment.
  * Updated Czech, Dutch, Italian, Portuguese, and Spanish
    translations.
* Wed Nov  7 2018 Luigi Baldoni <aloisio@gmx.com>
- Add oldsetuptools.patch to fix build on Leap 42.3 and SLE_12_SP3
* Tue Nov  6 2018 Marcus Rueckert <mrueckert@suse.de>
- Update to 0.9.13
  - Added support for Sigma X3F file format.
  - Added support for installing into a Python virtual environment.
    See the file README.rst for installation instructions. Thanks
    to Matthias Homann for his code contribution.
  - Fix bug #1797479: New version check results in confusing
    messages on stderr when pip is not installed. Thanks to Eli
    Schwartz for the fix.
  - Added Deepin to supported Linux distributions.
  - Fixed bug #1801504: PyQt5_sip not installed or upgraded for
    local user when system copy already installed (bug seen on
    Fedora 29).
  - Import sip regardless of whether it is the private sip bundled
    with PyQt5 or a separate sip installation.
- changes from 0.9.12
  - Added support for Canon CR3 format. Requires ExifTool 10.87 or
    newer.  See the release notes for details on upgrading
    ExifTool. Note: program performance with CR3 files is notably
    slower than other photo file formats.  Other photo file formats
    are read using the high performance library exiv2 to read
    metadata and extract thumbnails. Unfortunately exiv2 does not
    yet support the CR3 format. Exiv2 0.28 will support the CR3
    format.
  - Fixed bug #1790351: Video date time metadata not parsed
    correctly when 'DST' appears in time zone component.
  - Added support for FFF and IIQ raw formats.
  - The MOS and MRW formats are now handled by ExifTool, not exiv2.
  - Better handle Exif date time values that unwisely deviate from
    the Exif Version 2.3 specification, e.g. Hasselblad files.
  - Fixed bug #1790278: File renaming and subfolder generation
    editor breaks with Python 3.7.
  - Updated installation script to use "loose" instead of "strict"
    Python version checking.
  - Fixed bug in installation script where a system installed Rapid
    Photo Downloader package was not being uninstalled.
  - Fixed bug #1791131: Report fatal camera access problem without
    crashing
  - Improved install.py script to install libmediainfo0 on openSUSE
    where the package exists.
- changes from 0.9.11
  - Added CentOS 7.5 as supported Linux distribution. See the
    release notes for installation instructions.
  - Add weekday as locale's abbreviated and full name to file
    renaming and subfolder generation options.
  - Correct mistake in fixing bug #1775654: optional dependencies
    listed in setup.py as required.
  - Fix bug #1787707: install.py does not handle installer tar path
    with spaces.
  - Improve detection of openSUSE in install.py script.
  - Better handle file managers that do not allow the selection of
    files using command line arguments, which is important for
    desktops like Mate, LXDE, and XFCE.
  - Provide sensible fallback when system erroneously reports
    default file manager.
  - Updated Brazilian Portuguese, Czech, Dutch, French, Japanese,
    Kabyle, Norwegian Nynorsk, and Spanish translations.
- changes from 0.9.10
  - Fix bug #1784175: Make application compatible with changes to
    sip introduced in PyQt 5.11, and do not install PyQt 5.11 on
    systems with Python 3.5.3 or older.
  - Fix bug #1775654: optional dependencies listed in setup.py as
    required.
  - Fix bug #1755915: Crash while accessing non-existant SQL
    database 'cache' while exiting.
  - Fix bug #1764167: Division by zero error when scanning device
    that does not report its size
  - Fix bug #1774411: splash screen covering name-dialog when set
    to auto- download
  - Fixed bug in Appstream specification.
  - Updated German translation.
- refresh disable-version-check.patch
* Tue Apr 24 2018 aloisio@gmx.com
- Update to version 0.9.9
  * Fix bug #1750879: Sequence numbers increment incorrectly for
    videos when Synchronize RAW+JPEG enabled.
  * Fix bug in sequence letter generation.
  * Enable the disabling of new version checks in both the
    program logic and the user interface, which is useful for
    Linux distributions. To disable the check, Linux package
    maintainers should patch the file constants.py to
    change the line `disable_version_check = False` to
    `disable_version_check = True`.
  * Include tornado as a dependency instead of relying on the
    deprecated mini-tornado found in pyzmq.
  version 0.9.8:
  * On Sony files, use ExifTool to get shutter count metadata.
    Please note, not all Sony models produce this metadata.
- Added disable-version-check.patch
* Tue Jan 30 2018 jengelh@inai.de
- Replace description to say something about the software's
  functionality.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to version 0.9.7
  * Fixed bug where removing a download source while another source
    was being scanned could cause a crash when the timeline was
    scrolled.
  * Fixed bug where session sequence values were being reset every
    time a download was initiated, not every time the program was
    started.
  * Updated German, Hungarian and Norwegian Bokmal translations.
  * Fix bug #1738174: Don't crash when right clicking in thumbnail
    checkbox and no thumbnail is selected.
  * Fix bug #1737416: Don't scan cameras when browsing "This
    Computer", and detect if a camera mount has been passed via
    the command line (which can happen when the program
    automatically launches in response to a camera being attached
    to the computer).
  * When opening a file in KDE's Dolphin file manager, select the
    file (and thus highlight it), like is done with Gnome Files and
    several other file managers.
  * Fix bug #1737287: Don't allow identical entries in subfolder
    generation and file renaming presets, where the preset names
    differ but their content is the same.
  version  0.9.6:
  * When scrolling is synchronized, and you click on a thumbnail,
    the top of the Timeline will be scrolled match to match it.
  * Don't crash when only new files are displayed and the Timeline
    is scrolled when scrolling is synchronized.
  * Updated Czech, Dutch, Hungarian, Japanese, Russian, and Spanish
    translations.
  * Don't crash when Timeline ranges are selected and scrolling is
    synchronized.
  * The Timeline is now shown by default when the program is first
    run, or settings are reset.
  * Added option to synchronize Timeline with thumbnails. Scroll
    one, and the other automatically scrolls too. Use the button
    at the bottom-right of the Timeline to toggle this feature.
  * After clearing a Timeline selection, the display of thumbnails
    will be positioned such that the the photos in the previous
    selection are visible. Previously, the thumbnails display would
    be scrolled all the way to the top after the Timeline selection
    had been cleared.
  * Added Hasselblad 3FR files to list of supported file formats.
    If you detect any problems with the accuracy of the metadata
    from this format, please let me know.
  * Work around MediaInfoLib bug #695 that caused the libmediainfo
    shared object file to be named incorrectly, making it appear
    to be missing.
  * Correctly parse Distribution version in installer when running
    on Fedora, Debian and Peppermint.
  * Install PyQt 5.9.2 or greater. Upgrade pymediainfo to version
    2.2.0 or newer.
  * Updated Catalan, Chinese, Czech, Danish, Dutch, French, German,
    Norwegian Nyorsk, Russian, and Spanish translations.
  version 0.9.5:
  * Added check to install.py installation script and upgrade.py
    upgrade script to ensure that SIP 4.19.3 is installed when
    PyQt 5.9 is installed. The combination of SIP  4.19.4 and
    PyQt 5.9 causes Rapid Photo Downloader to crash. Because SIP
    4.19.4 is installed by default when installing PyQt 5.9, the
    install and upgrade scripts forcibly revert to
    SIP 4.19.3 when PyQt 5.9 is installed.
  * Add option to manually mark files as previously downloaded,
    allowing for occasions when another program has already
    downloaded the files. Right-click on one or more photo or video
    thumbnails to mark them as previously downloaded.
  * Add elementary OS to list of Linux distributions supported by
    the install.py script.
  * Fixed bug in upgrade script when reporting an operational
    failure.
  * Updated Chinese, Dutch, Italian, and Norwegian Bokmal
    translations.
  version 0.9.4:
  * Workaround bug in iOS devices that create on-the-fly subfolders
    from which to download that vary each time the device is
    initialized.
  * Add progress bars and badge counts when running under Ubuntu
    17.10's Dash to Dock extension.
  * Don't crash when locale is not correctly set.
  * Updated Dutch, French and German translations.
* Fri Sep 15 2017 aloisio@gmx.com
- Added python3-pyzmq version requirement
* Fri Sep 15 2017 zaitor@opensuse.org
- Update to version 0.9.3:
  + When requesting GIO to unmount a camera / phone so it can be
    accessed by libgphoto2, retry several times if it fails.
    Sometimes a GIO client program such as Gnome Files needs a few
    seconds to relinquish control of the device.
  + Fixed bug where a crash could occur when removing a camera that
    was in the preliminary stages of being scanned.
  + Fixed a bug introduced in 0.9.3b1 where photo and video numbers
    and sizes were not displayed in the devices summary in the
    program's left-hand pane.
  + Fixed a bug on Fedora where the maximum length for an sqlite3
    query could be exceeded.
  + When running a user-installed python such as Anaconda or
    another custom python, where possible the install.py script now
    switches over to using the Linux distribution's system python.
  + Under Python 3.6 or newer, bumped required version of pyzmq up
    to 16.0.2, hopefully avoiding a segfault observed with pyzmq
    15.1.0 and ZeroMQ 4.1.5. See the Release Notes for more
    details.
  + Updated translations.
* Mon Sep 11 2017 dimstar@opensuse.org
- Use automatic dependencies detection for typelib():
  + Add gobject-introspection BuildRequires (which contains the
    parser and rpm logic).
  + Drop the static typelib-1_0-* Requires.
  + As openSUSE does not provide Unity, filter out typelib(Unity)
    from the automatic dependency list.
* Sun Sep 10 2017 aloisio@gmx.com
- Added missing runtime dependency, fixes (boo#1057972)
* Mon Aug 28 2017 aloisio@gmx.com
- Set correct license
* Sun Aug 27 2017 aloisio@gmx.com
- Update to version 0.9.2
  * When displaying the time in the Timeline in a locale that
    does not use a twelve hour clock, correctly display the time
    using the 24 hour clock. If the times or dates being displayed
    in the Timeline are not displayed correctly in your language,
    please file a bug report.
  * Fixed a bug where an exception could occur when clicking on
    some Timeline entries or displaying their thumbnails as a
    tooltip. It occurred when the Timeline had one or more entries
    in the right-most column that spanned more than one calendar
    day. The code that generates the Timeline is among the most
    complex in the application. If you notice any problems, please
    file a bug report.
  * When a download device is inserted and downloaded files are
    already in the main window, the program will now ask if the
    completed downloads should be cleared. A new, associated program
    preference controls if the program should query and what action
    to take.
  * Improved visual appearance of preferences window.
  * Fixed a bug where the thumbnail extractors might crash when
    the thumbnail cache database had not yet been created, which
    could happen in unusual circumstances such as when the disk was
    under particularly heavy load.
  * Fixed bug extracting date/time metadata from videos where
    devices that create videos from which metadata cannot be
    extracted until the entire video is downloaded from the device.
  * When running LXQt, now assume the default file manager is
    pcmanfm-qt, regardless of what the mime-type handler reports.
    URIs passed to it now have the specific file stripped from the
    path, avoiding errors with pcmanfm-qt opening it. Currently,
    compared to more mature platforms like Gnome, LXQt has
    limitations that limit Rapid Photo Downloader's
    functionality.
  * Added uninstall and uninstall including dependencies options
    to the install.py script.
  * Added localization to the install.py script. The install
    script now embeds the files needed for localization, and
    utilizes them if needed.
  * The install.py script now checks key installation folders for
    ownership and permission problems, fixing them if necessary.
  * The install.py script now correctly parses openSUSE's zypper
    output to ascertain distribution packages that are already
    installed, saving time during installation.
  * In install.py, catch return code 104 from zypper se when no
    package is found.
  * Added support for Peppermint OS to the install.py script.
  * Terminate program at startup if the program's own module
    imports are being loaded from conflicting sources, indicating
    more than one copy of the program has been installed.
  * Report gphoto2 errors on the command line and Error Reports
    window with the name of the error rather than its numeric code.
  * Catch file permission errors more effectively in copy, rename,
    and backup processes.
  * Fixed bug when deleting certain sample videos from a device
    that had already been removed.
  * Updated Belarusian, Chinese (Simplified), Czech, Dutch, French,
    German, Hungarian, Japanese, Norwegian Bokmal, Norwegian
    Nynorsk, Russian and Spanish translations.
  * Applied a patch from Mikael Wiesel to fix a bug where several
    strings were not available for translation. Additionally made
    available for translation some buttons whose text was
    untranslated. Moreover, humanized times such as "one hour ago"
    (all of which are generated using the python library Arrow)
    are now localized where Arrow supports it. Finally,
    date/times in tooltips that appear over thumbnails are now
    localized, and locale date / times are used in download
    subfolder and filename generation for values like months.
* Sat Jul 15 2017 aloisio@gmx.com
- Update to version 0.9.1 (see CHANGES.rst)
- Switched to python3
- Split separate -lang file
- Dropped rapid-photo-downloader-rpmlintrc
- Spec cleanup
* Tue Jan  6 2015 firebird209@gmail.com
- Update to 0.4.11 For details see Changelog
  * Updated Brazilian, Catalan, Croatian, Czech, German, Japanese,
    Norwegian, Polish, Portuguese and Swedish translations.
  * Fixed crash on systems using the library Pillow 3.0.
  * Updated AppData file.
* Tue Mar  4 2014 toganm@opensuse.org
- Update to 0.4.10 For details see Changelog
  * Updated Catalan and Portuguese translations.
  * Fixed bug in translations for term "Back up".
* Tue Jan 28 2014 toganm@opensuse.org
- Update to 0.4.9 For details see Changelog
  * Updated Catalan and Spanish and Swedish translations.
  * Fixed occasional incorrect use of term "backup".
* Wed Jan 15 2014 toganm@opensuse.org
- Update to 0.4.8 For details see Changelog
  * Fixed bug lp#1263237: Added support for MPO files (3D images).
  * Fixed bug lp#1263483: Some terms in the user interface are not
    being translated.
  * Updated Dutch, French Italian, Polish and Spanish translations.
* Thu Oct 24 2013 toganm@opensuse.org
- Update to 0.4.7 For details see Changelog
  * Added feature to download audio files that are associated with
    photos such as those created by the Canon 1D series of cameras.
  * Fixed bug #1242119: In Ubuntu 13.10, choosing a destination or
    source folder from its bookmark does not work. The correct value
    is displayed in the file chooser button, but this value is not
    used by Rapid Photo Downloader. Earlier versions of Ubuntu were
    unaffected.
  * Fixed bug #1206853: Crashes when system message notifications not
    functioning properly.
  * Fixed bug #909405: Allow selections by row (and not GTK default
    by square) when user is dragging the mouse or using the keyboard
    to select.
  * Added a KDE Solid action. Solid is KDE4's hardware-related
    framework. It detects when the user connects a new device and
    display a list of related actions. Thanks to dju` for the patch.
  * Added Belarusian translation—thanks go to Ilya Tsimokhin. Updated
    Swedish and Ukrainian translations.
* Thu Jan 24 2013 toganm@opensuse.org
- Update to 0.4.6 For details see Changelog
  * Fixed bug lp#1083756: Application shows duplicate sources.
  * Fixed bug lp#1093330: Photo rename ignores SubSeconds when 00.
  * Updated German and Spanish translations.
  * Added extra debugging output to help trace program execution
    progress.
- added fdupes to buildrequires to fix duplicate files
* Thu Jul  5 2012 toganm@opensuse.org
- removed man page compression as rpm does this byitself
* Wed Jul  4 2012 toganm@opensuse.org
- Update to 0.4.5 For details see Changelog
  * Updated Dutch, Estonian, German, Italian, Norwegian and Polish
    translations.
  * Updated man page.
  * Fixed bug #1014203: Very poor program performance after download
    device changed. The program now displays the results of scanning
    files much quicker if the program's download device preferences
    are changed and a scan begins of a new device.
  * Fixed bug #1014219: File Modify process crashes if program exits
    during download.
* Wed May 30 2012 toganm@opensuse.org
- Update to 0.4.4 For details see Changelog
  * Fixed bug #998320: Applied patch from Dmitry Kazimirov for
    option to have subfolder generation and file renaming use a
    month in text format.
  * Fixed bug #986681: Crash when showing question dialog on some
    non-Gnome systems.
  * Fixed bug #995769: The Help button in the preferences dialog
    does not work.
  * Fixed bug #996613: Updated Free Software Foundation address.
  * Added Estonian translation. Updated Brazilian, Dutch, French,
    German, Norwegian Bokmal, Polish, Spanish and Russian
    translations.
* Tue May  8 2012 toganm@opensuse.org
- add perl-Image-ExifTool gdk-pixbuf-loader-rsvg to requires
* Tue May  1 2012 toganm@opensuse.org
- update to 0.4.3 For details see ChangeLog :
  * ExifTool is now a required dependency for Rapid Photo Downloader.
    ExifTool can be used to help download videos on Linux distributions
    that have not packaged hachoir-metadata.
  * Exiftran is another new dependency. It is used to automatically
    rotate JPEG images.
  * Fixed bug #704482: Delete photos option should be easily accessible
  * Fixed bug #754531: extract Exif.CanonFi.FileNumber metadata
  * Fixed bug #695517: Added functionality to download MTS video files.
  * Fixed bug #859998: Download THM video thumbnail files
  * Fixed bug #594533: Lossless JPEG rotation based on EXIF data after
    picture transfer
  * Fixed bug #859012: Confirm if really want to download from /home,
    /media or /
- Use the original source files
- Follow openSUSE license format
- Include ChangeLog AUTHORS COPYING in the docs
- Use license for the spec itself
* Fri Apr 29 2011 pascal.bleser@opensuse.org
- update to 0.4.0:
  * clean new user interface
  * imports about 3 times faster
  * ability to select multiple files to check or uncheck for downloading
  * adds automation feature to delete downloaded files from a device
  * backups have been implemented
  * adds a preferences option for disabling thumbnail generation
  * fixes a crash that occurred when downloading some files after having
    previously downloaded others in the same session
  * adds Job Code functionality
  * adds an eject device button for each unmountable device
  * adds display of remaining files to be downloaded in the progress bar
  * adds display of overall download progress in the lower progress bar
  * adds display of time remaining and download speed in the status bar
  * adds system notification messages
  * adds new automation features: auto download, auto exit, and auto unmount
  * bugfix: display file and subfolder naming warnings in error log
  * adds an error log window to display download warnings and errors
  * adds a feature to synchronize RAW + JPEG sequence values
* Fri Mar 25 2011 pascal.bleser@opensuse.org
- update to 0.3.5:
  * fix bug #714039, where under certain circumstances the program could crash
    while downloading files
  * added Romanian translation. Updated Brazilian, Chinese, Croatian, Czech,
    Dutch, Finnish, German, Italian, Polish and Russian translations
* Sun Jan  2 2011 pascal.bleser@opensuse.org
- update to 0.3.4:
  * you can now zoom in and out of a preview image
  * extraneous white space is now more effectively stripped from serial number metadata and folder names
  * a Croatian translation was added
  * the French, Norwegian Bokmal, Polish, and Russian translations were updated
  * other minor fixes were made
* Wed Oct 27 2010 pascal.bleser@opensuse.org
- update to 0.3.3:
  * adds support for mod, tod, and 3gp video files
  * adds preliminary support for Samusung SRW files
  * generation of subfolders and filenames using the time a download was started
  * hachoir-metadata is now used to extract selected metadata from video files
  * fixes for bugs related to a missing video download directory at program startup
  * a command line option to output to the terminal information, which is useful for debugging
  * Norwegian Bokmal and Portuguese translations
  * updates to many other translations
* Mon Sep 13 2010 pascal.bleser@opensuse.org
- update to 0.3.2:
  * adds a Norwegian Nynorsk translation
  * updates the Chinese, Finnish, Hungarian, Dutch, Occitan (post 1500), Polish, Brazilian Portuguese, and Russian translations
  * fixes crash on startup when checking for free space and the download folder does not exist
* Fri Aug 13 2010 pascal.bleser@opensuse.org
- update to 0.3.1:
  * main window now works more effectively on tiny screens like netbooks
  * amount of free space available on the filesystem where photos are to be downloaded is now displayed in the status bar
  * added or updated many translations: Chinese (simplified), Bulgarian, Japanese, Occitan (post 1500), Persian, Portuguese (Brazilian), and Turkish have been added; updated Finnish, French, Hungarian, Russian, Serbian and Spanish translations
* Sun Jul 11 2010 pascal.bleser@opensuse.org
- update to 0.3.0:
  * the major new feature of this release is the generation of previews before a download takes place: you can now select which photos and videos you wish to download
  * you can now assign different job codes to photos and videos in the same download: simply select photos and videos, and from the main window choose a job code for them
  * the errors and warnings reported have been completely overhauled, and are now more concise
* Mon Jun  7 2010 pascal.bleser@opensuse.org
- update to 0.2.2:
  * adds an Ukranian translation
  * no longer crashes on startup when exiv2 is not installed
* Sun Jun  6 2010 pascal.bleser@opensuse.org
- update to 0.2.1:
  * Bug fix: display sample photo and video names in preferences
    dialog using first photo and video found on download device,
    where possible -- this used to work but was inadvertently
    disabled in a recent release
  * Bug fix: prompt for Job code when only video names or video
    subfolder names use a job code
  * bug fix: filter out Null bytes from Exif string values -- these
    can occur when the Exif data is corrupted
  * translation updates for Spanish, Russian and Finnish
* Mon May 31 2010 pascal.bleser@opensuse.org
- update to 0.2.0:
  * video download functionality was added
  * the use of version 0.2.x of the pyexiv2 library was enabled
  * a bug in which sometimes images could not be downloaded to NTFS
    partitions was fixed
  * error message headings in the Error Log are now displayed in a
    red font
  * program settings and preferences can be reset using a new
    command line option
* Sun Feb 14 2010 pascal.bleser@opensuse.org
- update to 0.1.3:
  * fixed bug #509348: when both the backup and "Delete images
    from image device upon download completion" options are
    selected, the program will only delete an image from the image
    device if it was both downloaded to the download folder and
    backed up; previously it did not check to ensure it was backed
    up correctly too
  * fixed bug #505492: the program previously failed to start in
    environments where the notification system has problems
  * fixed bug #508304: the user is now prompted to confirm if they
    really want to remove all of their Job Codes after clicking on
    "Remove All" in the preferences dialog window
  * fixed bug #510484: previously, the program could crash when
    attempting to download to a read-only folder
  * fixed bug #510516: the program now checks to see if the
    download folder exists and is writeable; if automatic detection
    of image devices is not enabled, it checks to see if the image
    location path exists
- changes from 0.1.2:
  * new feature: photographers using RAW + JPEG mode now have the
    option to synchronize sequence numbers for the matching pair
    of images: this option is useful if you use the RAW + JPEG
    feature on your camera and you use sequence numbers or letters
    in your image renaming; enabling this option will cause the
    program to detect matching pairs of RAW and JPEG images, and
    when they are detected, the same sequence numbers and letters
    will be applied to both image names; furthermore, sequences
    will be updated as if the images were one
  * increased maximum sequence number length to seven digits by
    user request
  * fixed bug #503704: changes in values for downloads today and
    stored number not updated when changed via program preferences
    while a download is ready to begin
- changes from 0.1.1:
  * aded auto delete feature. When enabled, upon the completion of
    a download, images that were successfully downloaded will be
    deleted from the image device they were downloaded from;
    images that were not downloaded successfully will not be
    deleted
  * added keyboard accelerators for Preferences and Help
- changes from 0.1.0:
  * added icons to notification messages
  * bug fix: properly handle devices being unmounted, fixing a bug
    introduced in Version 0.0.9 beta 2
  * bug fix: when program preferences are changed, image and backup
    devices are now refreshed only when the preferences dialog
    window is closed
  * bug fix: minutes component of image and folder renaming had the
    same code as months
  * fixed bug #484432: error in adding job codes via the
    preferences dialog
  * fixed bug #486886: job code prompt can appear multiple times
  * added a "Job codes" option
  * added additional hour, minute and second options in image
    renaming and subfolder creation
  * fixed bug #478620: problem with corrupted image files
  * fixed bug #479424: some camera model names do not have numbers,
    but it still makes sense to return a shortened name
  * fixed bug #482831: program no longer crashes when auto-download
    is off, and a device is inserted before another download has
    completed
* Sat Oct 17 2009 pascal.bleser@opensuse.org
- initial package: 0.0.10
